# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ChangeComplexRelationTypeRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'public_id': 'str',
        'name': 'str',
        'description': 'str',
        'color': 'str',
        'symbol_type': 'str',
        'icon_code': 'str',
        'acronym_code': 'str',
        'attribute_types': 'list[ComplexRelationAttributeTypeRequest]',
        'leg_types': 'list[ComplexRelationLegTypeRequest]'
    }

    attribute_map = {
        'public_id': 'publicId',
        'name': 'name',
        'description': 'description',
        'color': 'color',
        'symbol_type': 'symbolType',
        'icon_code': 'iconCode',
        'acronym_code': 'acronymCode',
        'attribute_types': 'attributeTypes',
        'leg_types': 'legTypes'
    }

    def __init__(self, public_id=None, name=None, description=None, color=None, symbol_type=None, icon_code=None, acronym_code=None, attribute_types=None, leg_types=None):  # noqa: E501
        """ChangeComplexRelationTypeRequest - a model defined in Swagger"""  # noqa: E501
        self._public_id = None
        self._name = None
        self._description = None
        self._color = None
        self._symbol_type = None
        self._icon_code = None
        self._acronym_code = None
        self._attribute_types = None
        self._leg_types = None
        self.discriminator = None
        if public_id is not None:
            self.public_id = public_id
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if color is not None:
            self.color = color
        if symbol_type is not None:
            self.symbol_type = symbol_type
        if icon_code is not None:
            self.icon_code = icon_code
        if acronym_code is not None:
            self.acronym_code = acronym_code
        if attribute_types is not None:
            self.attribute_types = attribute_types
        if leg_types is not None:
            self.leg_types = leg_types

    @property
    def public_id(self):
        """Gets the public_id of this ChangeComplexRelationTypeRequest.  # noqa: E501

        The new public id for the Complex Relation Type. It must be unique within all Asset Types, Complex Relation Types, Domain Types and Scopes. It should contain only ASCII letters and digits. It must start with an uppercase ASCII character. It must end with \"_C\". WARNING : The public id should only be changed with extreme caution, since it can break existing customizations. The only valid use case is to change it after creation of the type, if no public id was specified, and the generated proposal is not acceptable.  # noqa: E501

        :return: The public_id of this ChangeComplexRelationTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._public_id

    @public_id.setter
    def public_id(self, public_id):
        """Sets the public_id of this ChangeComplexRelationTypeRequest.

        The new public id for the Complex Relation Type. It must be unique within all Asset Types, Complex Relation Types, Domain Types and Scopes. It should contain only ASCII letters and digits. It must start with an uppercase ASCII character. It must end with \"_C\". WARNING : The public id should only be changed with extreme caution, since it can break existing customizations. The only valid use case is to change it after creation of the type, if no public id was specified, and the generated proposal is not acceptable.  # noqa: E501

        :param public_id: The public_id of this ChangeComplexRelationTypeRequest.  # noqa: E501
        :type: str
        """

        self._public_id = public_id

    @property
    def name(self):
        """Gets the name of this ChangeComplexRelationTypeRequest.  # noqa: E501

        The new name for the Complex Relation Type.  # noqa: E501

        :return: The name of this ChangeComplexRelationTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ChangeComplexRelationTypeRequest.

        The new name for the Complex Relation Type.  # noqa: E501

        :param name: The name of this ChangeComplexRelationTypeRequest.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this ChangeComplexRelationTypeRequest.  # noqa: E501

        The new description for the Complex Relation Type.  # noqa: E501

        :return: The description of this ChangeComplexRelationTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ChangeComplexRelationTypeRequest.

        The new description for the Complex Relation Type.  # noqa: E501

        :param description: The description of this ChangeComplexRelationTypeRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def color(self):
        """Gets the color of this ChangeComplexRelationTypeRequest.  # noqa: E501

        The color of the symbol, in a hex format e.g. '#000000'.  This format always includes the '#' and has a size of 7.  # noqa: E501

        :return: The color of this ChangeComplexRelationTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._color

    @color.setter
    def color(self, color):
        """Sets the color of this ChangeComplexRelationTypeRequest.

        The color of the symbol, in a hex format e.g. '#000000'.  This format always includes the '#' and has a size of 7.  # noqa: E501

        :param color: The color of this ChangeComplexRelationTypeRequest.  # noqa: E501
        :type: str
        """

        self._color = color

    @property
    def symbol_type(self):
        """Gets the symbol_type of this ChangeComplexRelationTypeRequest.  # noqa: E501

        The new symbol type.  # noqa: E501

        :return: The symbol_type of this ChangeComplexRelationTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._symbol_type

    @symbol_type.setter
    def symbol_type(self, symbol_type):
        """Sets the symbol_type of this ChangeComplexRelationTypeRequest.

        The new symbol type.  # noqa: E501

        :param symbol_type: The symbol_type of this ChangeComplexRelationTypeRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["NONE", "ICON_CODE", "ACRONYM_CODE"]  # noqa: E501
        if symbol_type not in allowed_values:
            raise ValueError(
                "Invalid value for `symbol_type` ({0}), must be one of {1}"  # noqa: E501
                .format(symbol_type, allowed_values)
            )

        self._symbol_type = symbol_type

    @property
    def icon_code(self):
        """Gets the icon_code of this ChangeComplexRelationTypeRequest.  # noqa: E501

        The new icon code for the Complex Relation Type.  # noqa: E501

        :return: The icon_code of this ChangeComplexRelationTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._icon_code

    @icon_code.setter
    def icon_code(self, icon_code):
        """Sets the icon_code of this ChangeComplexRelationTypeRequest.

        The new icon code for the Complex Relation Type.  # noqa: E501

        :param icon_code: The icon_code of this ChangeComplexRelationTypeRequest.  # noqa: E501
        :type: str
        """

        self._icon_code = icon_code

    @property
    def acronym_code(self):
        """Gets the acronym_code of this ChangeComplexRelationTypeRequest.  # noqa: E501

        The new acronym code for the Complex Relation Type.  # noqa: E501

        :return: The acronym_code of this ChangeComplexRelationTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._acronym_code

    @acronym_code.setter
    def acronym_code(self, acronym_code):
        """Sets the acronym_code of this ChangeComplexRelationTypeRequest.

        The new acronym code for the Complex Relation Type.  # noqa: E501

        :param acronym_code: The acronym_code of this ChangeComplexRelationTypeRequest.  # noqa: E501
        :type: str
        """

        self._acronym_code = acronym_code

    @property
    def attribute_types(self):
        """Gets the attribute_types of this ChangeComplexRelationTypeRequest.  # noqa: E501

        The new list of attribute types for the Complex Relation Type.  # noqa: E501

        :return: The attribute_types of this ChangeComplexRelationTypeRequest.  # noqa: E501
        :rtype: list[ComplexRelationAttributeTypeRequest]
        """
        return self._attribute_types

    @attribute_types.setter
    def attribute_types(self, attribute_types):
        """Sets the attribute_types of this ChangeComplexRelationTypeRequest.

        The new list of attribute types for the Complex Relation Type.  # noqa: E501

        :param attribute_types: The attribute_types of this ChangeComplexRelationTypeRequest.  # noqa: E501
        :type: list[ComplexRelationAttributeTypeRequest]
        """

        self._attribute_types = attribute_types

    @property
    def leg_types(self):
        """Gets the leg_types of this ChangeComplexRelationTypeRequest.  # noqa: E501

        The new list of leg types for the Complex Relation Type.  # noqa: E501

        :return: The leg_types of this ChangeComplexRelationTypeRequest.  # noqa: E501
        :rtype: list[ComplexRelationLegTypeRequest]
        """
        return self._leg_types

    @leg_types.setter
    def leg_types(self, leg_types):
        """Sets the leg_types of this ChangeComplexRelationTypeRequest.

        The new list of leg types for the Complex Relation Type.  # noqa: E501

        :param leg_types: The leg_types of this ChangeComplexRelationTypeRequest.  # noqa: E501
        :type: list[ComplexRelationLegTypeRequest]
        """

        self._leg_types = leg_types

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ChangeComplexRelationTypeRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChangeComplexRelationTypeRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from collibra_core.api_client import ApiClient


class ViewPermissionsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_view_permission(self, **kwargs):  # noqa: E501
        """Adds a view permission. It can be applied only to 'Community' and 'Domain' resource types.  # noqa: E501

        Adds a view permission. It can be applied only to 'Community' and 'Domain' resource types.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_view_permission(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddViewPermissionRequest body: Properties of the new view permission. Valid resource types are: 'Community', 'Domain'.
        :return: ViewPermissionImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_view_permission_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.add_view_permission_with_http_info(**kwargs)  # noqa: E501
            return data

    def add_view_permission_with_http_info(self, **kwargs):  # noqa: E501
        """Adds a view permission. It can be applied only to 'Community' and 'Domain' resource types.  # noqa: E501

        Adds a view permission. It can be applied only to 'Community' and 'Domain' resource types.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_view_permission_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddViewPermissionRequest body: Properties of the new view permission. Valid resource types are: 'Community', 'Domain'.
        :return: ViewPermissionImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_view_permission" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/viewPermissions', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ViewPermissionImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_view_permissions(self, **kwargs):  # noqa: E501
        """Finds view permissions with given criteria.  # noqa: E501

        Finds view permissions with given criteria.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_view_permissions(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used. The maximum allowed limit is 1000.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param str user_id: The ID of the user for whom the view permission applies.
        :param str user_group_id: The ID of the user group for whose members the view permission applies.
        :param str resource_id: The ID of the community or domain to which the view permissions apply.
        :param str resource_type: Deprecated. Use <code>Community</code> or <code>Domain</code> to only retrieve view permissions assigned directly on a community or domain respectively. Do not use this filter in conjunction with the <code>resourceId</code> parameter.
        :param bool include_inherited: When you provide a <code>resourceId</code>, setting this parameter to <code>true</code> also returns the view permissions inherited from a parent community.
        :return: PagedResponseViewPermission
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.find_view_permissions_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.find_view_permissions_with_http_info(**kwargs)  # noqa: E501
            return data

    def find_view_permissions_with_http_info(self, **kwargs):  # noqa: E501
        """Finds view permissions with given criteria.  # noqa: E501

        Finds view permissions with given criteria.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_view_permissions_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used. The maximum allowed limit is 1000.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param str user_id: The ID of the user for whom the view permission applies.
        :param str user_group_id: The ID of the user group for whose members the view permission applies.
        :param str resource_id: The ID of the community or domain to which the view permissions apply.
        :param str resource_type: Deprecated. Use <code>Community</code> or <code>Domain</code> to only retrieve view permissions assigned directly on a community or domain respectively. Do not use this filter in conjunction with the <code>resourceId</code> parameter.
        :param bool include_inherited: When you provide a <code>resourceId</code>, setting this parameter to <code>true</code> also returns the view permissions inherited from a parent community.
        :return: PagedResponseViewPermission
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['offset', 'limit', 'count_limit', 'user_id', 'user_group_id', 'resource_id', 'resource_type', 'include_inherited']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_view_permissions" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'count_limit' in params:
            query_params.append(('countLimit', params['count_limit']))  # noqa: E501
        if 'user_id' in params:
            query_params.append(('userId', params['user_id']))  # noqa: E501
        if 'user_group_id' in params:
            query_params.append(('userGroupId', params['user_group_id']))  # noqa: E501
        if 'resource_id' in params:
            query_params.append(('resourceId', params['resource_id']))  # noqa: E501
        if 'resource_type' in params:
            query_params.append(('resourceType', params['resource_type']))  # noqa: E501
        if 'include_inherited' in params:
            query_params.append(('includeInherited', params['include_inherited']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/viewPermissions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResponseViewPermission',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_view_permission(self, view_permission_id, **kwargs):  # noqa: E501
        """Retrieves a view permission.  # noqa: E501

        Retrieves a view permission.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_view_permission(view_permission_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str view_permission_id: Identifier of the view permission to retrieve. (required)
        :return: ViewPermissionImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_view_permission_with_http_info(view_permission_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_view_permission_with_http_info(view_permission_id, **kwargs)  # noqa: E501
            return data

    def get_view_permission_with_http_info(self, view_permission_id, **kwargs):  # noqa: E501
        """Retrieves a view permission.  # noqa: E501

        Retrieves a view permission.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_view_permission_with_http_info(view_permission_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str view_permission_id: Identifier of the view permission to retrieve. (required)
        :return: ViewPermissionImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['view_permission_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_view_permission" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'view_permission_id' is set
        if ('view_permission_id' not in params or
                params['view_permission_id'] is None):
            raise ValueError("Missing the required parameter `view_permission_id` when calling `get_view_permission`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'view_permission_id' in params:
            path_params['viewPermissionId'] = params['view_permission_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/viewPermissions/{viewPermissionId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ViewPermissionImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_view_permission(self, view_permission_id, **kwargs):  # noqa: E501
        """Removes a view permission.  # noqa: E501

        Removes a view permission.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_view_permission(view_permission_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str view_permission_id: Identifier of the view permission to remove. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_view_permission_with_http_info(view_permission_id, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_view_permission_with_http_info(view_permission_id, **kwargs)  # noqa: E501
            return data

    def remove_view_permission_with_http_info(self, view_permission_id, **kwargs):  # noqa: E501
        """Removes a view permission.  # noqa: E501

        Removes a view permission.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_view_permission_with_http_info(view_permission_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str view_permission_id: Identifier of the view permission to remove. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['view_permission_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_view_permission" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'view_permission_id' is set
        if ('view_permission_id' not in params or
                params['view_permission_id'] is None):
            raise ValueError("Missing the required parameter `view_permission_id` when calling `remove_view_permission`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'view_permission_id' in params:
            path_params['viewPermissionId'] = params['view_permission_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/viewPermissions/{viewPermissionId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from collibra_core.api_client import ApiClient


class CommunitiesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_communities(self, **kwargs):  # noqa: E501
        """Add multiple communities  # noqa: E501

        Adds multiple communities with the given parameters  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_communities(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[AddCommunityRequest] body: List of the properties of the communities to be added.
        :return: list[CommunityImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_communities_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.add_communities_with_http_info(**kwargs)  # noqa: E501
            return data

    def add_communities_with_http_info(self, **kwargs):  # noqa: E501
        """Add multiple communities  # noqa: E501

        Adds multiple communities with the given parameters  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_communities_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[AddCommunityRequest] body: List of the properties of the communities to be added.
        :return: list[CommunityImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_communities" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/communities/bulk', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CommunityImpl]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def add_community(self, **kwargs):  # noqa: E501
        """Add community  # noqa: E501

        Adds a new community with the given parameters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_community(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddCommunityRequest body: the properties of the community to be added
        :return: CommunityImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_community_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.add_community_with_http_info(**kwargs)  # noqa: E501
            return data

    def add_community_with_http_info(self, **kwargs):  # noqa: E501
        """Add community  # noqa: E501

        Adds a new community with the given parameters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_community_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddCommunityRequest body: the properties of the community to be added
        :return: CommunityImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_community" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/communities', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CommunityImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_communities(self, **kwargs):  # noqa: E501
        """Change multiple communities  # noqa: E501

        Changes multiple communities using the given request parameters  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_communities(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[ChangeCommunityRequest] body: List of the properties of the communities to be changed.
        :return: list[CommunityImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_communities_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.change_communities_with_http_info(**kwargs)  # noqa: E501
            return data

    def change_communities_with_http_info(self, **kwargs):  # noqa: E501
        """Change multiple communities  # noqa: E501

        Changes multiple communities using the given request parameters  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_communities_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[ChangeCommunityRequest] body: List of the properties of the communities to be changed.
        :return: list[CommunityImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_communities" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/communities/bulk', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CommunityImpl]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_community(self, community_id, **kwargs):  # noqa: E501
        """Change community  # noqa: E501

        Changes the community with the information that is present in the request. Only properties that are specified in this request and have non-<code>null</code> values are updated. All other properties are ignored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_community(community_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str community_id: the id of the community to be changed. (required)
        :param ChangeCommunityRequest body: the properties of the community to be changed
        :return: CommunityImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_community_with_http_info(community_id, **kwargs)  # noqa: E501
        else:
            (data) = self.change_community_with_http_info(community_id, **kwargs)  # noqa: E501
            return data

    def change_community_with_http_info(self, community_id, **kwargs):  # noqa: E501
        """Change community  # noqa: E501

        Changes the community with the information that is present in the request. Only properties that are specified in this request and have non-<code>null</code> values are updated. All other properties are ignored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_community_with_http_info(community_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str community_id: the id of the community to be changed. (required)
        :param ChangeCommunityRequest body: the properties of the community to be changed
        :return: CommunityImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['community_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_community" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'community_id' is set
        if ('community_id' not in params or
                params['community_id'] is None):
            raise ValueError("Missing the required parameter `community_id` when calling `change_community`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'community_id' in params:
            path_params['communityId'] = params['community_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/communities/{communityId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CommunityImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_to_root_community(self, community_id, **kwargs):  # noqa: E501
        """Change to root community  # noqa: E501

        Changes the community with given ID to a root community.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_to_root_community(community_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str community_id: The ID of the community that will be changed to a root community (required)
        :return: CommunityImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_to_root_community_with_http_info(community_id, **kwargs)  # noqa: E501
        else:
            (data) = self.change_to_root_community_with_http_info(community_id, **kwargs)  # noqa: E501
            return data

    def change_to_root_community_with_http_info(self, community_id, **kwargs):  # noqa: E501
        """Change to root community  # noqa: E501

        Changes the community with given ID to a root community.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_to_root_community_with_http_info(community_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str community_id: The ID of the community that will be changed to a root community (required)
        :return: CommunityImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['community_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_to_root_community" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'community_id' is set
        if ('community_id' not in params or
                params['community_id'] is None):
            raise ValueError("Missing the required parameter `community_id` when calling `change_to_root_community`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'community_id' in params:
            path_params['communityId'] = params['community_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/communities/{communityId}/root', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CommunityImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_communities(self, sort_field, **kwargs):  # noqa: E501
        """Find communities  # noqa: E501

        Returns communities matching the given search criteria. Only parameters that are specified in this request and have non-<code>null</code> values are used for filtering. All other parameters are ignored. By default a result containing 1000 communities is returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_communities(sort_field, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str sort_field: The field on which the results are sorted. (required)
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>. Cursor should be preferred over offset for better performance and stable results. It is forbidden to use both in the same request.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used. The maximum allowed limit is 1000.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped. For cursor pagination this parameter is ignored and count is skipped.
        :param str cursor: Cursor for the current page of results. To retrieve the first page with cursor pagination you need to pass this parameter with an empty value (must be non-null). For the next pages, the value must be taken from the response (<code>nextCursor</code> property).
        :param str name: The name of the community to search for.
        :param str name_match_mode: The match mode used to compare <code>name</code>. If the match mode is <code>EXACT</code> the search is case-sensitive, otherwise the search is case-insensitive.
        :param str parent_id: The ID of the parent community to find the communities in.
        :param bool exclude_meta: The exclude meta flag. If this is set to true then the meta communities will not be returned (meta communities are i.e. communities not created manually by the user).
        :param str sort_order: The sorting order.
        :return: CommunityPagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.find_communities_with_http_info(sort_field, **kwargs)  # noqa: E501
        else:
            (data) = self.find_communities_with_http_info(sort_field, **kwargs)  # noqa: E501
            return data

    def find_communities_with_http_info(self, sort_field, **kwargs):  # noqa: E501
        """Find communities  # noqa: E501

        Returns communities matching the given search criteria. Only parameters that are specified in this request and have non-<code>null</code> values are used for filtering. All other parameters are ignored. By default a result containing 1000 communities is returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_communities_with_http_info(sort_field, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str sort_field: The field on which the results are sorted. (required)
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>. Cursor should be preferred over offset for better performance and stable results. It is forbidden to use both in the same request.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used. The maximum allowed limit is 1000.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped. For cursor pagination this parameter is ignored and count is skipped.
        :param str cursor: Cursor for the current page of results. To retrieve the first page with cursor pagination you need to pass this parameter with an empty value (must be non-null). For the next pages, the value must be taken from the response (<code>nextCursor</code> property).
        :param str name: The name of the community to search for.
        :param str name_match_mode: The match mode used to compare <code>name</code>. If the match mode is <code>EXACT</code> the search is case-sensitive, otherwise the search is case-insensitive.
        :param str parent_id: The ID of the parent community to find the communities in.
        :param bool exclude_meta: The exclude meta flag. If this is set to true then the meta communities will not be returned (meta communities are i.e. communities not created manually by the user).
        :param str sort_order: The sorting order.
        :return: CommunityPagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['sort_field', 'offset', 'limit', 'count_limit', 'cursor', 'name', 'name_match_mode', 'parent_id', 'exclude_meta', 'sort_order']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_communities" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'sort_field' is set
        if ('sort_field' not in params or
                params['sort_field'] is None):
            raise ValueError("Missing the required parameter `sort_field` when calling `find_communities`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'count_limit' in params:
            query_params.append(('countLimit', params['count_limit']))  # noqa: E501
        if 'cursor' in params:
            query_params.append(('cursor', params['cursor']))  # noqa: E501
        if 'name' in params:
            query_params.append(('name', params['name']))  # noqa: E501
        if 'name_match_mode' in params:
            query_params.append(('nameMatchMode', params['name_match_mode']))  # noqa: E501
        if 'parent_id' in params:
            query_params.append(('parentId', params['parent_id']))  # noqa: E501
        if 'exclude_meta' in params:
            query_params.append(('excludeMeta', params['exclude_meta']))  # noqa: E501
        if 'sort_field' in params:
            query_params.append(('sortField', params['sort_field']))  # noqa: E501
        if 'sort_order' in params:
            query_params.append(('sortOrder', params['sort_order']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/communities', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CommunityPagedResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_community(self, community_id, **kwargs):  # noqa: E501
        """Get community  # noqa: E501

        Returns the community with the given ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_community(community_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str community_id: the ID of the community (required)
        :return: CommunityImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_community_with_http_info(community_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_community_with_http_info(community_id, **kwargs)  # noqa: E501
            return data

    def get_community_with_http_info(self, community_id, **kwargs):  # noqa: E501
        """Get community  # noqa: E501

        Returns the community with the given ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_community_with_http_info(community_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str community_id: the ID of the community (required)
        :return: CommunityImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['community_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_community" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'community_id' is set
        if ('community_id' not in params or
                params['community_id'] is None):
            raise ValueError("Missing the required parameter `community_id` when calling `get_community`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'community_id' in params:
            path_params['communityId'] = params['community_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/communities/{communityId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CommunityImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_community_breadcrumb(self, community_id, **kwargs):  # noqa: E501
        """Get community breadcrumb  # noqa: E501

        Returns the list of communities that lead to the community identified by the given ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_community_breadcrumb(community_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str community_id: The ID of the community (required)
        :return: list[NamedResourceReferenceImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_community_breadcrumb_with_http_info(community_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_community_breadcrumb_with_http_info(community_id, **kwargs)  # noqa: E501
            return data

    def get_community_breadcrumb_with_http_info(self, community_id, **kwargs):  # noqa: E501
        """Get community breadcrumb  # noqa: E501

        Returns the list of communities that lead to the community identified by the given ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_community_breadcrumb_with_http_info(community_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str community_id: The ID of the community (required)
        :return: list[NamedResourceReferenceImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['community_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_community_breadcrumb" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'community_id' is set
        if ('community_id' not in params or
                params['community_id'] is None):
            raise ValueError("Missing the required parameter `community_id` when calling `get_community_breadcrumb`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'community_id' in params:
            path_params['communityId'] = params['community_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/communities/{communityId}/breadcrumb', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[NamedResourceReferenceImpl]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_communities(self, **kwargs):  # noqa: E501
        """Remove multiple communities  # noqa: E501

        This endpoint will be removed in the future. Please use POST /communities/removalJobs.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_communities(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] body: the IDs of the communities to be removed, i.e. ["6f685f90-1036-4d30-983a-a9bbcdd7b8f6", "6f685f90-1036-4d30-983a-a9bbcdd7b123"]
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_communities_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.remove_communities_with_http_info(**kwargs)  # noqa: E501
            return data

    def remove_communities_with_http_info(self, **kwargs):  # noqa: E501
        """Remove multiple communities  # noqa: E501

        This endpoint will be removed in the future. Please use POST /communities/removalJobs.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_communities_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] body: the IDs of the communities to be removed, i.e. ["6f685f90-1036-4d30-983a-a9bbcdd7b8f6", "6f685f90-1036-4d30-983a-a9bbcdd7b123"]
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_communities" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/communities/bulk', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_communities_in_job(self, **kwargs):  # noqa: E501
        """Remove multiple communities asynchronously  # noqa: E501

        Removes multiple communities in a job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_communities_in_job(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] body: the IDs of the communities to be removed, i.e. ["6f685f90-1036-4d30-983a-a9bbcdd7b8f6", "6f685f90-1036-4d30-983a-a9bbcdd7b123"]
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_communities_in_job_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.remove_communities_in_job_with_http_info(**kwargs)  # noqa: E501
            return data

    def remove_communities_in_job_with_http_info(self, **kwargs):  # noqa: E501
        """Remove multiple communities asynchronously  # noqa: E501

        Removes multiple communities in a job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_communities_in_job_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] body: the IDs of the communities to be removed, i.e. ["6f685f90-1036-4d30-983a-a9bbcdd7b8f6", "6f685f90-1036-4d30-983a-a9bbcdd7b123"]
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_communities_in_job" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/communities/removalJobs', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Job',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_community(self, community_id, **kwargs):  # noqa: E501
        """Remove community  # noqa: E501

        This endpoint will be removed in the future. Please use POST /communities/removalJobs  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_community(community_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str community_id: the ID of the community to remove (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_community_with_http_info(community_id, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_community_with_http_info(community_id, **kwargs)  # noqa: E501
            return data

    def remove_community_with_http_info(self, community_id, **kwargs):  # noqa: E501
        """Remove community  # noqa: E501

        This endpoint will be removed in the future. Please use POST /communities/removalJobs  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_community_with_http_info(community_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str community_id: the ID of the community to remove (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['community_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_community" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'community_id' is set
        if ('community_id' not in params or
                params['community_id'] is None):
            raise ValueError("Missing the required parameter `community_id` when calling `remove_community`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'community_id' in params:
            path_params['communityId'] = params['community_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/communities/{communityId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.responsibilities_api import ResponsibilitiesApi  # noqa: E501
from collibra_core.rest import ApiException


class TestResponsibilitiesApi(unittest.TestCase):
    """ResponsibilitiesApi unit test stubs"""

    def setUp(self):
        self.api = ResponsibilitiesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_responsibilities(self):
        """Test case for add_responsibilities

        Adds multiple responsibilities in one go.  # noqa: E501
        """
        pass

    def test_add_responsibility(self):
        """Test case for add_responsibility

        Adds a new responsibility.  # noqa: E501
        """
        pass

    def test_find_responsibilities(self):
        """Test case for find_responsibilities

        Finds responsibilities.  # noqa: E501
        """
        pass

    def test_get_responsibility(self):
        """Test case for get_responsibility

        Returns the responsibility identified by the given id.  # noqa: E501
        """
        pass

    def test_remove_responsibilities(self):
        """Test case for remove_responsibilities

        Removes multiple responsibilities in one go.  # noqa: E501
        """
        pass

    def test_remove_responsibility(self):
        """Test case for remove_responsibility

        Removes the responsibility identified by the given id.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ChangeScopeRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'public_id': 'str',
        'name': 'str',
        'description': 'str',
        'domain_ids': 'list[str]',
        'community_ids': 'list[str]'
    }

    attribute_map = {
        'public_id': 'publicId',
        'name': 'name',
        'description': 'description',
        'domain_ids': 'domainIds',
        'community_ids': 'communityIds'
    }

    def __init__(self, public_id=None, name=None, description=None, domain_ids=None, community_ids=None):  # noqa: E501
        """ChangeScopeRequest - a model defined in Swagger"""  # noqa: E501
        self._public_id = None
        self._name = None
        self._description = None
        self._domain_ids = None
        self._community_ids = None
        self.discriminator = None
        if public_id is not None:
            self.public_id = public_id
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if domain_ids is not None:
            self.domain_ids = domain_ids
        if community_ids is not None:
            self.community_ids = community_ids

    @property
    def public_id(self):
        """Gets the public_id of this ChangeScopeRequest.  # noqa: E501

        The new public id for the Scope. It must be unique within all Asset Types, Complex Relation Types, Domain Types and Scopes. It should contain only ASCII letters and digits. It must start with an uppercase ASCII character. It must end with \"_C\". WARNING : The public id should only be changed with extreme caution, since it can break existing customizations. The only valid use case is to change it after creation of the type, if no public id was specified, and the generated proposal is not acceptable.  # noqa: E501

        :return: The public_id of this ChangeScopeRequest.  # noqa: E501
        :rtype: str
        """
        return self._public_id

    @public_id.setter
    def public_id(self, public_id):
        """Sets the public_id of this ChangeScopeRequest.

        The new public id for the Scope. It must be unique within all Asset Types, Complex Relation Types, Domain Types and Scopes. It should contain only ASCII letters and digits. It must start with an uppercase ASCII character. It must end with \"_C\". WARNING : The public id should only be changed with extreme caution, since it can break existing customizations. The only valid use case is to change it after creation of the type, if no public id was specified, and the generated proposal is not acceptable.  # noqa: E501

        :param public_id: The public_id of this ChangeScopeRequest.  # noqa: E501
        :type: str
        """

        self._public_id = public_id

    @property
    def name(self):
        """Gets the name of this ChangeScopeRequest.  # noqa: E501

        The new name for the scope  # noqa: E501

        :return: The name of this ChangeScopeRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ChangeScopeRequest.

        The new name for the scope  # noqa: E501

        :param name: The name of this ChangeScopeRequest.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this ChangeScopeRequest.  # noqa: E501

        The new description for the scope  # noqa: E501

        :return: The description of this ChangeScopeRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ChangeScopeRequest.

        The new description for the scope  # noqa: E501

        :param description: The description of this ChangeScopeRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def domain_ids(self):
        """Gets the domain_ids of this ChangeScopeRequest.  # noqa: E501

        The new list of IDs of domains that should included in the scope  # noqa: E501

        :return: The domain_ids of this ChangeScopeRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._domain_ids

    @domain_ids.setter
    def domain_ids(self, domain_ids):
        """Sets the domain_ids of this ChangeScopeRequest.

        The new list of IDs of domains that should included in the scope  # noqa: E501

        :param domain_ids: The domain_ids of this ChangeScopeRequest.  # noqa: E501
        :type: list[str]
        """

        self._domain_ids = domain_ids

    @property
    def community_ids(self):
        """Gets the community_ids of this ChangeScopeRequest.  # noqa: E501

        The new list of IDs of communities that should included in the scope  # noqa: E501

        :return: The community_ids of this ChangeScopeRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._community_ids

    @community_ids.setter
    def community_ids(self, community_ids):
        """Sets the community_ids of this ChangeScopeRequest.

        The new list of IDs of communities that should included in the scope  # noqa: E501

        :param community_ids: The community_ids of this ChangeScopeRequest.  # noqa: E501
        :type: list[str]
        """

        self._community_ids = community_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ChangeScopeRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChangeScopeRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from collibra_core.api_client import ApiClient


class UserGroupsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_user_group(self, **kwargs):  # noqa: E501
        """Add new user group  # noqa: E501

        Adds a new user group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_user_group(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddUserGroupRequest body:
        :return: UserGroupImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_user_group_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.add_user_group_with_http_info(**kwargs)  # noqa: E501
            return data

    def add_user_group_with_http_info(self, **kwargs):  # noqa: E501
        """Add new user group  # noqa: E501

        Adds a new user group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_user_group_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AddUserGroupRequest body:
        :return: UserGroupImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_user_group" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/userGroups', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserGroupImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def add_users_to_user_group(self, user_group_id, **kwargs):  # noqa: E501
        """Add users to user group  # noqa: E501

        Adds users to an existing user group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_users_to_user_group(user_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_group_id: The ID of the user group (required)
        :param AddUsersToUserGroupRequest body:
        :return: list[User]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_users_to_user_group_with_http_info(user_group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.add_users_to_user_group_with_http_info(user_group_id, **kwargs)  # noqa: E501
            return data

    def add_users_to_user_group_with_http_info(self, user_group_id, **kwargs):  # noqa: E501
        """Add users to user group  # noqa: E501

        Adds users to an existing user group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_users_to_user_group_with_http_info(user_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_group_id: The ID of the user group (required)
        :param AddUsersToUserGroupRequest body:
        :return: list[User]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_group_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_users_to_user_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_group_id' is set
        if ('user_group_id' not in params or
                params['user_group_id'] is None):
            raise ValueError("Missing the required parameter `user_group_id` when calling `add_users_to_user_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_group_id' in params:
            path_params['userGroupId'] = params['user_group_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/userGroups/{userGroupId}/users', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[User]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_user_group(self, user_group_id, **kwargs):  # noqa: E501
        """Change user group  # noqa: E501

        Changes the user group with the information that is present in the request. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_user_group(user_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_group_id: The ID of the user group (required)
        :param ChangeUserGroupRequest body:
        :return: UserGroupImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_user_group_with_http_info(user_group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.change_user_group_with_http_info(user_group_id, **kwargs)  # noqa: E501
            return data

    def change_user_group_with_http_info(self, user_group_id, **kwargs):  # noqa: E501
        """Change user group  # noqa: E501

        Changes the user group with the information that is present in the request. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_user_group_with_http_info(user_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_group_id: The ID of the user group (required)
        :param ChangeUserGroupRequest body:
        :return: UserGroupImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_group_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_user_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_group_id' is set
        if ('user_group_id' not in params or
                params['user_group_id'] is None):
            raise ValueError("Missing the required parameter `user_group_id` when calling `change_user_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_group_id' in params:
            path_params['userGroupId'] = params['user_group_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/userGroups/{userGroupId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserGroupImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_user_groups(self, **kwargs):  # noqa: E501
        """Find user groups  # noqa: E501

        Returns user groups matching the given search criteria. Only parameters that are specified in this request and have not <code>null</code> values are used for filtering. All other parameters are ignored. By default a result containing 1000 user groups is returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_user_groups(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used. The maximum allowed limit is 1000.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param str name: The name of the user group.
        :param str name_match_mode: The match mode used to compare <code>name</code>. If the match mode is <code>EXACT</code> the search is case-sensitive, otherwise the search is case-insensitive.
        :param str user_id: The ID of the user who should belong to searched user groups.
        :param bool include_everyone: Indicates if we should include the everyone group or not.
        :return: UserGroupPagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.find_user_groups_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.find_user_groups_with_http_info(**kwargs)  # noqa: E501
            return data

    def find_user_groups_with_http_info(self, **kwargs):  # noqa: E501
        """Find user groups  # noqa: E501

        Returns user groups matching the given search criteria. Only parameters that are specified in this request and have not <code>null</code> values are used for filtering. All other parameters are ignored. By default a result containing 1000 user groups is returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_user_groups_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used. The maximum allowed limit is 1000.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param str name: The name of the user group.
        :param str name_match_mode: The match mode used to compare <code>name</code>. If the match mode is <code>EXACT</code> the search is case-sensitive, otherwise the search is case-insensitive.
        :param str user_id: The ID of the user who should belong to searched user groups.
        :param bool include_everyone: Indicates if we should include the everyone group or not.
        :return: UserGroupPagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['offset', 'limit', 'count_limit', 'name', 'name_match_mode', 'user_id', 'include_everyone']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_user_groups" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'count_limit' in params:
            query_params.append(('countLimit', params['count_limit']))  # noqa: E501
        if 'name' in params:
            query_params.append(('name', params['name']))  # noqa: E501
        if 'name_match_mode' in params:
            query_params.append(('nameMatchMode', params['name_match_mode']))  # noqa: E501
        if 'user_id' in params:
            query_params.append(('userId', params['user_id']))  # noqa: E501
        if 'include_everyone' in params:
            query_params.append(('includeEveryone', params['include_everyone']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/userGroups', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserGroupPagedResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_user_group(self, user_group_id, **kwargs):  # noqa: E501
        """Get user group  # noqa: E501

        Returns the user group with the given ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_group(user_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_group_id: The ID of the user group (required)
        :return: UserGroupImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_user_group_with_http_info(user_group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_user_group_with_http_info(user_group_id, **kwargs)  # noqa: E501
            return data

    def get_user_group_with_http_info(self, user_group_id, **kwargs):  # noqa: E501
        """Get user group  # noqa: E501

        Returns the user group with the given ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_group_with_http_info(user_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_group_id: The ID of the user group (required)
        :return: UserGroupImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_group_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_group_id' is set
        if ('user_group_id' not in params or
                params['user_group_id'] is None):
            raise ValueError("Missing the required parameter `user_group_id` when calling `get_user_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_group_id' in params:
            path_params['userGroupId'] = params['user_group_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/userGroups/{userGroupId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserGroupImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_user_group(self, user_group_id, **kwargs):  # noqa: E501
        """Remove user group  # noqa: E501

        Removes the user group with the given ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_user_group(user_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_group_id: The ID of the user group (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_user_group_with_http_info(user_group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_user_group_with_http_info(user_group_id, **kwargs)  # noqa: E501
            return data

    def remove_user_group_with_http_info(self, user_group_id, **kwargs):  # noqa: E501
        """Remove user group  # noqa: E501

        Removes the user group with the given ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_user_group_with_http_info(user_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_group_id: The ID of the user group (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_group_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_user_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_group_id' is set
        if ('user_group_id' not in params or
                params['user_group_id'] is None):
            raise ValueError("Missing the required parameter `user_group_id` when calling `remove_user_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_group_id' in params:
            path_params['userGroupId'] = params['user_group_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/userGroups/{userGroupId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_users_from_user_group(self, user_group_id, **kwargs):  # noqa: E501
        """Remove users from user group  # noqa: E501

        Removes users from the user group with the given ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_users_from_user_group(user_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_group_id: The ID of the user group (required)
        :param RemoveUsersFromUserGroupRequest body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_users_from_user_group_with_http_info(user_group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_users_from_user_group_with_http_info(user_group_id, **kwargs)  # noqa: E501
            return data

    def remove_users_from_user_group_with_http_info(self, user_group_id, **kwargs):  # noqa: E501
        """Remove users from user group  # noqa: E501

        Removes users from the user group with the given ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_users_from_user_group_with_http_info(user_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_group_id: The ID of the user group (required)
        :param RemoveUsersFromUserGroupRequest body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_group_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_users_from_user_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_group_id' is set
        if ('user_group_id' not in params or
                params['user_group_id'] is None):
            raise ValueError("Missing the required parameter `user_group_id` when calling `remove_users_from_user_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_group_id' in params:
            path_params['userGroupId'] = params['user_group_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/userGroups/{userGroupId}/users', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ComplexRelationAttributeTypeRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'min': 'int',
        'max': 'int',
        'attribute_type_id': 'str',
        'id': 'str'
    }

    attribute_map = {
        'min': 'min',
        'max': 'max',
        'attribute_type_id': 'attributeTypeId',
        'id': 'id'
    }

    def __init__(self, min=None, max=None, attribute_type_id=None, id=None):  # noqa: E501
        """ComplexRelationAttributeTypeRequest - a model defined in Swagger"""  # noqa: E501
        self._min = None
        self._max = None
        self._attribute_type_id = None
        self._id = None
        self.discriminator = None
        if min is not None:
            self.min = min
        if max is not None:
            self.max = max
        self.attribute_type_id = attribute_type_id
        if id is not None:
            self.id = id

    @property
    def min(self):
        """Gets the min of this ComplexRelationAttributeTypeRequest.  # noqa: E501

        The minimum number of Attribute Type occurrences.  # noqa: E501

        :return: The min of this ComplexRelationAttributeTypeRequest.  # noqa: E501
        :rtype: int
        """
        return self._min

    @min.setter
    def min(self, min):
        """Sets the min of this ComplexRelationAttributeTypeRequest.

        The minimum number of Attribute Type occurrences.  # noqa: E501

        :param min: The min of this ComplexRelationAttributeTypeRequest.  # noqa: E501
        :type: int
        """

        self._min = min

    @property
    def max(self):
        """Gets the max of this ComplexRelationAttributeTypeRequest.  # noqa: E501

        The maximum number of Attribute Type occurrences.  # noqa: E501

        :return: The max of this ComplexRelationAttributeTypeRequest.  # noqa: E501
        :rtype: int
        """
        return self._max

    @max.setter
    def max(self, max):
        """Sets the max of this ComplexRelationAttributeTypeRequest.

        The maximum number of Attribute Type occurrences.  # noqa: E501

        :param max: The max of this ComplexRelationAttributeTypeRequest.  # noqa: E501
        :type: int
        """

        self._max = max

    @property
    def attribute_type_id(self):
        """Gets the attribute_type_id of this ComplexRelationAttributeTypeRequest.  # noqa: E501

        The ID of the Attribute Type.  # noqa: E501

        :return: The attribute_type_id of this ComplexRelationAttributeTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._attribute_type_id

    @attribute_type_id.setter
    def attribute_type_id(self, attribute_type_id):
        """Sets the attribute_type_id of this ComplexRelationAttributeTypeRequest.

        The ID of the Attribute Type.  # noqa: E501

        :param attribute_type_id: The attribute_type_id of this ComplexRelationAttributeTypeRequest.  # noqa: E501
        :type: str
        """
        if attribute_type_id is None:
            raise ValueError("Invalid value for `attribute_type_id`, must not be `None`")  # noqa: E501

        self._attribute_type_id = attribute_type_id

    @property
    def id(self):
        """Gets the id of this ComplexRelationAttributeTypeRequest.  # noqa: E501

        The ID of the Complex Relation Attribute Type. If specified, it will be used to create a new Complex Relation Attribute Type if none exists, or as id for the existing Complex Relation Attribute Type. If not specified, a random id will be generated and used to create a new Complex Relation Attribute Type if none exists, or as id for the existing Complex Relation Attribute Type.  # noqa: E501

        :return: The id of this ComplexRelationAttributeTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ComplexRelationAttributeTypeRequest.

        The ID of the Complex Relation Attribute Type. If specified, it will be used to create a new Complex Relation Attribute Type if none exists, or as id for the existing Complex Relation Attribute Type. If not specified, a random id will be generated and used to create a new Complex Relation Attribute Type if none exists, or as id for the existing Complex Relation Attribute Type.  # noqa: E501

        :param id: The id of this ComplexRelationAttributeTypeRequest.  # noqa: E501
        :type: str
        """

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ComplexRelationAttributeTypeRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ComplexRelationAttributeTypeRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AddAttributeTypeRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'public_id': 'str',
        'name': 'str',
        'description': 'str',
        'kind': 'str',
        'language': 'str',
        'statistics_enabled': 'bool',
        'allowed_values': 'list[str]',
        'string_type': 'str',
        'id_string': 'str',
        'is_integer': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'public_id': 'publicId',
        'name': 'name',
        'description': 'description',
        'kind': 'kind',
        'language': 'language',
        'statistics_enabled': 'statisticsEnabled',
        'allowed_values': 'allowedValues',
        'string_type': 'stringType',
        'id_string': 'idString',
        'is_integer': 'isInteger'
    }

    def __init__(self, id=None, public_id=None, name=None, description=None, kind=None, language=None, statistics_enabled=None, allowed_values=None, string_type=None, id_string=None, is_integer=None):  # noqa: E501
        """AddAttributeTypeRequest - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._public_id = None
        self._name = None
        self._description = None
        self._kind = None
        self._language = None
        self._statistics_enabled = None
        self._allowed_values = None
        self._string_type = None
        self._id_string = None
        self._is_integer = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if public_id is not None:
            self.public_id = public_id
        self.name = name
        if description is not None:
            self.description = description
        self.kind = kind
        if language is not None:
            self.language = language
        if statistics_enabled is not None:
            self.statistics_enabled = statistics_enabled
        if allowed_values is not None:
            self.allowed_values = allowed_values
        if string_type is not None:
            self.string_type = string_type
        if id_string is not None:
            self.id_string = id_string
        if is_integer is not None:
            self.is_integer = is_integer

    @property
    def id(self):
        """Gets the id of this AddAttributeTypeRequest.  # noqa: E501

        The ID of the new Attribute Type. Should be unique within all Attribute Types.<br/>It should have a format of universally unique identifier (UUID) and should not start with <code>00000000-0000-0000-</code> which is a reserved prefix.  # noqa: E501

        :return: The id of this AddAttributeTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AddAttributeTypeRequest.

        The ID of the new Attribute Type. Should be unique within all Attribute Types.<br/>It should have a format of universally unique identifier (UUID) and should not start with <code>00000000-0000-0000-</code> which is a reserved prefix.  # noqa: E501

        :param id: The id of this AddAttributeTypeRequest.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def public_id(self):
        """Gets the public_id of this AddAttributeTypeRequest.  # noqa: E501

        The public id that will be assigned to the new Attribute Type. It must be unique within all Attribute Types. It should contain only ASCII letters and digits. It must start with an uppercase ASCII character. It must end with \"_C\". If no public id is provided, a valid public id will be generated.  # noqa: E501

        :return: The public_id of this AddAttributeTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._public_id

    @public_id.setter
    def public_id(self, public_id):
        """Sets the public_id of this AddAttributeTypeRequest.

        The public id that will be assigned to the new Attribute Type. It must be unique within all Attribute Types. It should contain only ASCII letters and digits. It must start with an uppercase ASCII character. It must end with \"_C\". If no public id is provided, a valid public id will be generated.  # noqa: E501

        :param public_id: The public_id of this AddAttributeTypeRequest.  # noqa: E501
        :type: str
        """

        self._public_id = public_id

    @property
    def name(self):
        """Gets the name of this AddAttributeTypeRequest.  # noqa: E501

        The name of the new Attribute Type. Should be unique within all Attribute Types.  # noqa: E501

        :return: The name of this AddAttributeTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AddAttributeTypeRequest.

        The name of the new Attribute Type. Should be unique within all Attribute Types.  # noqa: E501

        :param name: The name of this AddAttributeTypeRequest.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this AddAttributeTypeRequest.  # noqa: E501

        The description of the new Attribute Type.  # noqa: E501

        :return: The description of this AddAttributeTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this AddAttributeTypeRequest.

        The description of the new Attribute Type.  # noqa: E501

        :param description: The description of this AddAttributeTypeRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def kind(self):
        """Gets the kind of this AddAttributeTypeRequest.  # noqa: E501

        The kind of the new Attribute Type.  # noqa: E501

        :return: The kind of this AddAttributeTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._kind

    @kind.setter
    def kind(self, kind):
        """Sets the kind of this AddAttributeTypeRequest.

        The kind of the new Attribute Type.  # noqa: E501

        :param kind: The kind of this AddAttributeTypeRequest.  # noqa: E501
        :type: str
        """
        if kind is None:
            raise ValueError("Invalid value for `kind`, must not be `None`")  # noqa: E501
        allowed_values = ["BOOLEAN", "STRING", "NUMERIC", "DATE", "SINGLE_VALUE_LIST", "MULTI_VALUE_LIST", "SCRIPT"]  # noqa: E501
        if kind not in allowed_values:
            raise ValueError(
                "Invalid value for `kind` ({0}), must be one of {1}"  # noqa: E501
                .format(kind, allowed_values)
            )

        self._kind = kind

    @property
    def language(self):
        """Gets the language of this AddAttributeTypeRequest.  # noqa: E501

        The language of the new Attribute Type. This property is only applicable to Attribute Types of kind \"Script\".  # noqa: E501

        :return: The language of this AddAttributeTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this AddAttributeTypeRequest.

        The language of the new Attribute Type. This property is only applicable to Attribute Types of kind \"Script\".  # noqa: E501

        :param language: The language of this AddAttributeTypeRequest.  # noqa: E501
        :type: str
        """

        self._language = language

    @property
    def statistics_enabled(self):
        """Gets the statistics_enabled of this AddAttributeTypeRequest.  # noqa: E501

        Whether statistics should be enabled. This property is only applicable to Attribute Types of kind \"Numeric\" or \"Boolean\".  # noqa: E501

        :return: The statistics_enabled of this AddAttributeTypeRequest.  # noqa: E501
        :rtype: bool
        """
        return self._statistics_enabled

    @statistics_enabled.setter
    def statistics_enabled(self, statistics_enabled):
        """Sets the statistics_enabled of this AddAttributeTypeRequest.

        Whether statistics should be enabled. This property is only applicable to Attribute Types of kind \"Numeric\" or \"Boolean\".  # noqa: E501

        :param statistics_enabled: The statistics_enabled of this AddAttributeTypeRequest.  # noqa: E501
        :type: bool
        """

        self._statistics_enabled = statistics_enabled

    @property
    def allowed_values(self):
        """Gets the allowed_values of this AddAttributeTypeRequest.  # noqa: E501

        List of allowed values. This property is only applicable to Attribute Types of kind \"Single Value List\" or \"Multi Value List\".  # noqa: E501

        :return: The allowed_values of this AddAttributeTypeRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._allowed_values

    @allowed_values.setter
    def allowed_values(self, allowed_values):
        """Sets the allowed_values of this AddAttributeTypeRequest.

        List of allowed values. This property is only applicable to Attribute Types of kind \"Single Value List\" or \"Multi Value List\".  # noqa: E501

        :param allowed_values: The allowed_values of this AddAttributeTypeRequest.  # noqa: E501
        :type: list[str]
        """

        self._allowed_values = allowed_values

    @property
    def string_type(self):
        """Gets the string_type of this AddAttributeTypeRequest.  # noqa: E501

        Rich text or plain text This property is only applicable to Attribute Types of kind \"String\".  # noqa: E501

        :return: The string_type of this AddAttributeTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._string_type

    @string_type.setter
    def string_type(self, string_type):
        """Sets the string_type of this AddAttributeTypeRequest.

        Rich text or plain text This property is only applicable to Attribute Types of kind \"String\".  # noqa: E501

        :param string_type: The string_type of this AddAttributeTypeRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["RICH_TEXT", "PLAIN_TEXT"]  # noqa: E501
        if string_type not in allowed_values:
            raise ValueError(
                "Invalid value for `string_type` ({0}), must be one of {1}"  # noqa: E501
                .format(string_type, allowed_values)
            )

        self._string_type = string_type

    @property
    def id_string(self):
        """Gets the id_string of this AddAttributeTypeRequest.  # noqa: E501

        The ID of the Attribute Type. This field will be removed in the future.  # noqa: E501

        :return: The id_string of this AddAttributeTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._id_string

    @id_string.setter
    def id_string(self, id_string):
        """Sets the id_string of this AddAttributeTypeRequest.

        The ID of the Attribute Type. This field will be removed in the future.  # noqa: E501

        :param id_string: The id_string of this AddAttributeTypeRequest.  # noqa: E501
        :type: str
        """

        self._id_string = id_string

    @property
    def is_integer(self):
        """Gets the is_integer of this AddAttributeTypeRequest.  # noqa: E501

        Whether Attribute Type holds an integer value. This property is only applicable to Attribute Types of kind \"Numeric\".  # noqa: E501

        :return: The is_integer of this AddAttributeTypeRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_integer

    @is_integer.setter
    def is_integer(self, is_integer):
        """Sets the is_integer of this AddAttributeTypeRequest.

        Whether Attribute Type holds an integer value. This property is only applicable to Attribute Types of kind \"Numeric\".  # noqa: E501

        :param is_integer: The is_integer of this AddAttributeTypeRequest.  # noqa: E501
        :type: bool
        """

        self._is_integer = is_integer

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AddAttributeTypeRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddAttributeTypeRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RelationTraceEntryImpl(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'out_bound_role_direction': 'bool',
        'role_direction': 'bool',
        'relation_type_id': 'str',
        'out_bound_relation_type_id': 'str'
    }

    attribute_map = {
        'out_bound_role_direction': 'outBoundRoleDirection',
        'role_direction': 'roleDirection',
        'relation_type_id': 'relationTypeId',
        'out_bound_relation_type_id': 'outBoundRelationTypeId'
    }

    def __init__(self, out_bound_role_direction=None, role_direction=None, relation_type_id=None, out_bound_relation_type_id=None):  # noqa: E501
        """RelationTraceEntryImpl - a model defined in Swagger"""  # noqa: E501
        self._out_bound_role_direction = None
        self._role_direction = None
        self._relation_type_id = None
        self._out_bound_relation_type_id = None
        self.discriminator = None
        if out_bound_role_direction is not None:
            self.out_bound_role_direction = out_bound_role_direction
        if role_direction is not None:
            self.role_direction = role_direction
        if relation_type_id is not None:
            self.relation_type_id = relation_type_id
        if out_bound_relation_type_id is not None:
            self.out_bound_relation_type_id = out_bound_relation_type_id

    @property
    def out_bound_role_direction(self):
        """Gets the out_bound_role_direction of this RelationTraceEntryImpl.  # noqa: E501

        Whether the outbound relation is followed in role direction.  # noqa: E501

        :return: The out_bound_role_direction of this RelationTraceEntryImpl.  # noqa: E501
        :rtype: bool
        """
        return self._out_bound_role_direction

    @out_bound_role_direction.setter
    def out_bound_role_direction(self, out_bound_role_direction):
        """Sets the out_bound_role_direction of this RelationTraceEntryImpl.

        Whether the outbound relation is followed in role direction.  # noqa: E501

        :param out_bound_role_direction: The out_bound_role_direction of this RelationTraceEntryImpl.  # noqa: E501
        :type: bool
        """

        self._out_bound_role_direction = out_bound_role_direction

    @property
    def role_direction(self):
        """Gets the role_direction of this RelationTraceEntryImpl.  # noqa: E501

        Whether the relation is followed in role direction, i.e. from source to target.  # noqa: E501

        :return: The role_direction of this RelationTraceEntryImpl.  # noqa: E501
        :rtype: bool
        """
        return self._role_direction

    @role_direction.setter
    def role_direction(self, role_direction):
        """Sets the role_direction of this RelationTraceEntryImpl.

        Whether the relation is followed in role direction, i.e. from source to target.  # noqa: E501

        :param role_direction: The role_direction of this RelationTraceEntryImpl.  # noqa: E501
        :type: bool
        """

        self._role_direction = role_direction

    @property
    def relation_type_id(self):
        """Gets the relation_type_id of this RelationTraceEntryImpl.  # noqa: E501

        The ID of the relation type.  # noqa: E501

        :return: The relation_type_id of this RelationTraceEntryImpl.  # noqa: E501
        :rtype: str
        """
        return self._relation_type_id

    @relation_type_id.setter
    def relation_type_id(self, relation_type_id):
        """Sets the relation_type_id of this RelationTraceEntryImpl.

        The ID of the relation type.  # noqa: E501

        :param relation_type_id: The relation_type_id of this RelationTraceEntryImpl.  # noqa: E501
        :type: str
        """

        self._relation_type_id = relation_type_id

    @property
    def out_bound_relation_type_id(self):
        """Gets the out_bound_relation_type_id of this RelationTraceEntryImpl.  # noqa: E501

        The ID of the outbound relation type.  # noqa: E501

        :return: The out_bound_relation_type_id of this RelationTraceEntryImpl.  # noqa: E501
        :rtype: str
        """
        return self._out_bound_relation_type_id

    @out_bound_relation_type_id.setter
    def out_bound_relation_type_id(self, out_bound_relation_type_id):
        """Sets the out_bound_relation_type_id of this RelationTraceEntryImpl.

        The ID of the outbound relation type.  # noqa: E501

        :param out_bound_relation_type_id: The out_bound_relation_type_id of this RelationTraceEntryImpl.  # noqa: E501
        :type: str
        """

        self._out_bound_relation_type_id = out_bound_relation_type_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RelationTraceEntryImpl, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RelationTraceEntryImpl):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from collibra_core.models.assigned_characteristic_type import AssignedCharacteristicType  # noqa: F401,E501

class AssignedRelationType(AssignedCharacteristicType):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'role_direction': 'str',
        'relation_type': 'RelationTypeImpl',
        'restriction': 'NamedResourceReferenceImpl'
    }
    if hasattr(AssignedCharacteristicType, "swagger_types"):
        swagger_types.update(AssignedCharacteristicType.swagger_types)

    attribute_map = {
        'role_direction': 'roleDirection',
        'relation_type': 'relationType',
        'restriction': 'restriction'
    }
    if hasattr(AssignedCharacteristicType, "attribute_map"):
        attribute_map.update(AssignedCharacteristicType.attribute_map)

    def __init__(self, role_direction=None, relation_type=None, restriction=None, *args, **kwargs):  # noqa: E501
        """AssignedRelationType - a model defined in Swagger"""  # noqa: E501
        self._role_direction = None
        self._relation_type = None
        self._restriction = None
        self.discriminator = None
        if role_direction is not None:
            self.role_direction = role_direction
        if relation_type is not None:
            self.relation_type = relation_type
        if restriction is not None:
            self.restriction = restriction
        AssignedCharacteristicType.__init__(self, *args, **kwargs)

    @property
    def role_direction(self):
        """Gets the role_direction of this AssignedRelationType.  # noqa: E501

        The direction of the relation type.  # noqa: E501

        :return: The role_direction of this AssignedRelationType.  # noqa: E501
        :rtype: str
        """
        return self._role_direction

    @role_direction.setter
    def role_direction(self, role_direction):
        """Sets the role_direction of this AssignedRelationType.

        The direction of the relation type.  # noqa: E501

        :param role_direction: The role_direction of this AssignedRelationType.  # noqa: E501
        :type: str
        """
        allowed_values = ["TO_SOURCE", "TO_TARGET", "BOTH", "NONE"]  # noqa: E501
        if role_direction not in allowed_values:
            raise ValueError(
                "Invalid value for `role_direction` ({0}), must be one of {1}"  # noqa: E501
                .format(role_direction, allowed_values)
            )

        self._role_direction = role_direction

    @property
    def relation_type(self):
        """Gets the relation_type of this AssignedRelationType.  # noqa: E501


        :return: The relation_type of this AssignedRelationType.  # noqa: E501
        :rtype: RelationTypeImpl
        """
        return self._relation_type

    @relation_type.setter
    def relation_type(self, relation_type):
        """Sets the relation_type of this AssignedRelationType.


        :param relation_type: The relation_type of this AssignedRelationType.  # noqa: E501
        :type: RelationTypeImpl
        """

        self._relation_type = relation_type

    @property
    def restriction(self):
        """Gets the restriction of this AssignedRelationType.  # noqa: E501


        :return: The restriction of this AssignedRelationType.  # noqa: E501
        :rtype: NamedResourceReferenceImpl
        """
        return self._restriction

    @restriction.setter
    def restriction(self, restriction):
        """Sets the restriction of this AssignedRelationType.


        :param restriction: The restriction of this AssignedRelationType.  # noqa: E501
        :type: NamedResourceReferenceImpl
        """

        self._restriction = restriction

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AssignedRelationType, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssignedRelationType):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
